gofts

package module
v0.0.0-...-dd3695c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 27, 2023 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Fts

func Fts(form map[string][]string, dest interface{}) error

Transfers form data into the struct specified by the user. Throws error if: [1] The dest is not a pointer to a struct, [2] Type conversion cannot be made. Unsupported types are ignored

func Mfts

func Mfts(form map[string][]string, dest ...interface{}) error

Transfers input form data into *multiple* structs specified by the user. The second argument accepts a list of structs Throws error if: [1] The dest is not a pointer to a struct, [2] Type conversion cannot be made. Unsupported types are ignored

Types

This section is empty.

Jump to