Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Fts ¶
Transfers form data into the struct specified by the user. Throws error if: [1] The dest is not a pointer to a struct, [2] Type conversion cannot be made. Unsupported types are ignored
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.